@@ -7,12 +7,17 @@ from common.config import Config
 from .app_base import ApplicationBase
 
 
-def application_entrypoint(application_class: Type[ApplicationBase], config: Config):
+def application_entrypoint(
+    application_class: Type[ApplicationBase], config: Config, argv=None
+):
     """
     The main entry point of the application.
     """
     # Parses the CLI arguments, and merge them into the configuration
-    config.apply_cli_args(sys.argv[1:])
+    if argv is None:
+        config.apply_cli_args(sys.argv[1:])
+    else:
+        config.apply_cli_args(argv)
 
     if config.get("DUMP_CONFIG"):
         config.dump()
